@@ -1,3 +1,7 @@
+// SPDX-FileCopyrightText: 2022 Gary Wang <wzc782970009@gmail.com>
+//
+// SPDX-License-Identifier: MIT
+
 #ifndef TOOLBUTTON_H
 #define TOOLBUTTON_H
 
@@ -9,6 +13,7 @@ class ToolButton : public QPushButton
     Q_OBJECT
 public:
     ToolButton(bool hoverColor = false, QWidget * parent = nullptr);
+    void setIconResourcePath(const QString &iconp);
 
 public slots:
     void setOpacity(qreal opacity, bool animated = true);
